@@ -3,8 +3,8 @@
 ;; Copyright (C) 2024-2026 James Cherti | https://www.jamescherti.com/contact/
 
 ;; Author: James Cherti <https://www.jamescherti.com/contact/>
-;; Package-Version: 20260215.2013
-;; Package-Revision: 344f18654e01
+;; Package-Version: 20260219.1358
+;; Package-Revision: 91d6d1c7a15f
 ;; URL: https://github.com/jamescherti/outline-indent.el
 ;; Keywords: outlines
 ;; Package-Requires: ((emacs "26.1"))
@@ -133,12 +133,6 @@ suitable for representing folded content."
   :type '(choice string (const nil))
   :group 'outline-indent)
 
-(define-obsolete-variable-alias
-  'outline-indent-make-window-start-visible
-  'make-window-start-visible
-  "1.1.4"
-  "Obsolete. Use `make-window-start-visible' instead.")
-
 (defcustom outline-indent-insert-heading-add-blank-line nil
   "Non-nil to make `outline-indent-insert-heading' add a blank line.
 
@@ -232,6 +226,11 @@ It is recommended to keep this set to t for improved behavior."
     (outline-indent--advise-func value))
   :group 'outline-indent)
 
+(defcustom outline-indent-ignored-modes '(org-mode markdown-mode)
+  "List of major modes where `outline-indent-minor-mode' will not start."
+  :type '(repeat symbol)
+  :group 'outline-indent)
+
 (defvar outline-indent-minor-mode-map
   (let ((map (make-sparse-keymap)))
     map)
@@ -370,26 +369,6 @@ follow the mode-specific coding style automatically."
       (unless outline-indent-shift-width
         (setq-local outline-indent-shift-width major-mode-offset)))))
 
-(defun outline-indent-level-ignore-empty-lines ()
-  "Determine the outline level based on the current indentation."
-  (let* ((indentation-string (match-string 1))
-         (indentation-width (if indentation-string
-                                (string-width indentation-string)
-                              0))
-         (depth (if (and (= indentation-width 0)
-                         (save-excursion
-                           (beginning-of-line)
-                           (looking-at-p "^\\s-*$")))
-                    0
-                  (+ 1 (/ indentation-width
-                          (max (if outline-indent-default-offset
-                                   outline-indent-default-offset
-                                 1)
-                               1))))))
-    (if outline-indent-maximum-level
-        (min depth (1+ outline-indent-maximum-level))
-      depth)))
-
 (defun outline-indent-level ()
   "Determine the outline level based on the current indentation."
   (let* ((indentation-width (current-indentation))
@@ -498,15 +477,6 @@ selection operations."
     (goto-char (region-beginning))
     (deactivate-mark)))
 
-(defun outline-indent--advice-promote (orig-fun &rest args)
-  "Advice function for `outline-indent-shift-left'.
-If `outline-indent-minor-mode' is active, use `outline-indent-insert-heading'.
-Otherwise, call the original function with the given arguments.
-ORIG-FUN is the original function being advised, and ARGS are its arguments."
-  (if (bound-and-true-p outline-indent-minor-mode)
-      (outline-indent-shift-left)
-    (apply orig-fun args)))
-
 (defun outline-indent--advice-show-entry (orig-fun &rest args)
   "Advice function for `outline-show-entry'.
 If `outline-indent-minor-mode' is active, use `outline-indent-open-fold'.
@@ -517,7 +487,7 @@ ORIG-FUN is the original function being advised, and ARGS are its arguments."
     (apply orig-fun args)))
 
 (defun outline-indent--advice-outline-hide-subtree (orig-fun &rest args)
-  "Advice function for `outline-hide-subtre'.
+  "Advice function for `outline-hide-subtree'.
 If `outline-indent-minor-mode' is active, use `outline-indent-close-fold'.
 Otherwise, call the original function with the given arguments. ORIG-FUN is the
 original function being advised, and ARGS are its arguments."
@@ -525,6 +495,15 @@ original function being advised, and ARGS are its arguments."
       (outline-indent-close-fold)
     (apply orig-fun args)))
 
+(defun outline-indent--advice-promote (orig-fun &rest args)
+  "Advice function for `outline-indent-shift-left'.
+If `outline-indent-minor-mode' is active, use `outline-indent-insert-heading'.
+Otherwise, call the original function with the given arguments.
+ORIG-FUN is the original function being advised, and ARGS are its arguments."
+  (if (bound-and-true-p outline-indent-minor-mode)
+      (outline-indent-shift-left)
+    (apply orig-fun args)))
+
 (defun outline-indent--advice-demote (orig-fun &rest args)
   "Advice function for `outline-indent-shift-right'.
 If `outline-indent-minor-mode' is active, use `outline-indent-insert-heading'.
@@ -808,10 +787,34 @@ visual region spanning from the heading start to the end of the block."
 (defun outline-indent-close-folds ()
   "Close all folds and ensure the first heading remains visible."
   (interactive)
-  (unwind-protect
-      (with-no-warnings
-        (outline-hide-sublevels 1))
-    (outline-indent--ensure-window-start-heading-visible)))
+  (save-excursion
+    (goto-char (point-min))
+
+    ;; Handle preamble (if the file doesn't start with a heading)
+    (unless (outline-on-heading-p)
+      (outline-next-heading))
+
+    ;; Collapse every top-level heading found
+    (let ((done nil))
+      (while (and (not done)
+                  (not (eobp))
+                  (outline-on-heading-p))
+        (let ((current-point (point)))
+          ;; Hide the subtree
+          (condition-case nil
+              (outline-indent--legacy-outline-hide-subtree)
+            (error
+             nil))
+
+          ;; Try to move to the next visible heading.
+          (progn
+            (outline-next-visible-heading 1)
+            ;; SAFETY CHECK: If point did not move forward, we
+            ;; must stop. This catches cases where the function
+            ;; returns successfully but fails to advance (e.g., at
+            ;; the last heading in some modes).
+            (when (<= (point) current-point)
+              (setq done t))))))))
 
 ;;;###autoload
 (defun outline-indent-open-folds ()
@@ -1025,6 +1028,20 @@ WHICH is ignored (backward compatibility with `outline-promote')."
 ;;          (group (zero-or-more (any " \t")))
 ;;          (not (any " \t\n")))))
 
+(defun outline-indent--setup-outline ()
+  "Enforce outline variables for `outline-indent-minor-mode'."
+  (when (boundp 'outline-minor-mode-highlight)
+    (setq-local outline-minor-mode-highlight nil))
+  (when (boundp 'outline-search-function)
+    (setq-local outline-search-function nil))
+  (setq-local outline-heading-alist nil)
+  (setq-local outline-level #'outline-indent-level)
+  (setq-local outline-heading-end-regexp "\n")
+  ;; (setq-local outline-regexp (outline-indent--heading-regexp))
+  (setq-local outline-regexp (rx line-start
+                                 (group (zero-or-more (any " \t")))
+                                 (not (any " \t\n")))))
+
 ;;;###autoload
 (define-minor-mode outline-indent-minor-mode
   "Minor mode for folding text according to indentation levels."
@@ -1033,31 +1050,30 @@ WHICH is ignored (backward compatibility with `outline-promote')."
   :group 'outline-indent
   (if outline-indent-minor-mode
       (progn
-        ;; Disable conflicting modes
-        (dolist (mode outline-indent-conflicting-modes)
-          (when (and (boundp mode)
-                     (symbol-value mode)
-                     (fboundp mode))
-            (save-excursion
-              (funcall mode -1))))
+        (let ((ignored-mode-p nil))
+          (dolist (mode outline-indent-ignored-modes)
+            (when (derived-mode-p mode)
+              (setq ignored-mode-p t)))
 
-        (outline-indent--advise-func outline-indent-advise-outline-functions)
+          (if ignored-mode-p
+              (setq outline-indent-minor-mode nil)
+            ;; Disable conflicting modes
+            (dolist (mode outline-indent-conflicting-modes)
+              (when (and (boundp mode)
+                         (symbol-value mode)
+                         (fboundp mode))
+                (save-excursion
+                  (funcall mode -1))))
 
-        ;; Enable minor mode
-        (when (boundp 'outline-minor-mode-highlight)
-          (setq-local outline-minor-mode-highlight nil))
-        (when (boundp 'outline-search-function)
-          (setq-local outline-search-function nil))
-        (setq-local outline-heading-alist nil)
-        (setq-local outline-level #'outline-indent-level)
-        (setq-local outline-heading-end-regexp "\n")
-        ;; (setq-local outline-regexp (outline-indent--heading-regexp))
-        (setq-local outline-regexp (rx line-start
-                                       (group (zero-or-more (any " \t")))
-                                       (not (any " \t\n"))))
-        (outline-indent--update-ellipsis)
-        (outline-indent--setup-basic-offset)
-        (outline-minor-mode 1))
+            (outline-indent--advise-func outline-indent-advise-outline-functions)
+
+            (outline-indent--update-ellipsis)
+            (outline-indent--setup-basic-offset)
+
+            ;; Enable minor mode
+            (outline-indent--setup-outline))
+
+          (outline-minor-mode 1)))
     ;; Disable minor mode
     (outline-minor-mode -1)
     (kill-local-variable 'outline-minor-mode-highlight)
